# `deluca`

Performant, differentiable reinforcement learning

## Notes
1. This is pre-alpha software and is undergoing a number of core changes. Updates to follow.
2. Documentation forthcoming!

[![pypi](https://badgen.net/pypi/v/deluca)](https://pypi.org/project/deluca/)
[![pyversions](https://raw.githubusercontent.com/google/deluca/main/.github/badges/python_versions.svg)](https://pypi.org/project/deluca)
[![security: bandit](https://raw.githubusercontent.com/google/deluca/main/.github/badges/bandit.svg)](https://github.com/PyCQA/bandit)
[![Code style: black](https://raw.githubusercontent.com/google/deluca/main/.github/badges/black.svg)](https://github.com/psf/black)
[![License: Apache 2.0](https://raw.githubusercontent.com/google/deluca/main/.github/badges/apache.svg)](https://github.com/google/deluca/blob/main/LICENSE)

[![build](https://github.com/google/deluca/workflows/build/badge.svg)](https://github.com/google/deluca/actions)
[![coverage](https://badgen.net/codecov/c/github/google/deluca)](https://codecov.io/github/google/deluca)
[![Documentation Status](https://readthedocs.org/projects/deluca/badge/?version=latest)](https://deluca.readthedocs.io/en/latest/?badge=latest)
[![doc_coverage](https://raw.githubusercontent.com/google/deluca/main/.github/badges/docstring_coverage.svg)](https://github.com/google/deluca)

![deluca](https://raw.githubusercontent.com/google/deluca/main/assets/img/deluca.svg?token=AAURLVRRLKHPK4VELPKH6X27RW5LC)
